@@ -1,10 +1,10 @@
 #!/bin/sh
 echo 'name: aeson
-version: 0.6.0.2
-id: aeson-0.6.0.2-157531de53c6d98f8fb3771b2b5cb201
+version: 0.6.2.1
+id: aeson-0.6.2.1-92173c75149e34c3bea9cafc379c1c76
 
 license: BSD3
-copyright: (c) 2011 Bryan O'\''Sullivan
+copyright: (c) 2011, 2012, 2013 Bryan O'\''Sullivan
            (c) 2011 MailRank, Inc.
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
 stability: experimental
@@ -20,11 +20,6 @@ description: A JSON parsing and encoding library optimized for ease of use
              For release notes, see
              <https://github.com/bos/aeson/blob/master/release-notes.markdown>
              .
-             /Note/: if you use GHCi or Template Haskell, please see the
-             @README@ file for important details about building this package,
-             and other packages that depend on it:
-             <https://github.com/bos/aeson#readme>
-             .
              Parsing performance on a late 2010 MacBook Pro (2.66GHz Core i7),
              for mostly-English tweets from Twitter'\''s JSON search API:
              .
@@ -87,35 +82,35 @@ hidden-modules: Data.Aeson.Types.Generic Data.Aeson.Functions
                 Data.Aeson.Parser.Internal Data.Aeson.Types.Class
                 Data.Aeson.Types.Internal
 trusted: False
-import-dirs: /usr/local/lib/ghc/aeson-0.6.0.2
-library-dirs: /usr/local/lib/ghc/aeson-0.6.0.2
-hs-libraries: HSaeson-0.6.0.2
+import-dirs: /usr/local/lib/ghc/aeson-0.6.2.1
+library-dirs: /usr/local/lib/ghc/aeson-0.6.2.1
+hs-libraries: HSaeson-0.6.2.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: attoparsec-0.10.1.0-3149dba69bd6a508e5a21c7e9cf969a8
-         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         blaze-builder-0.2.1.4-cbacb369ecb80a55dd55bab68eb21ee1
-         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
-         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
-         deepseq-1.3.0.0-c8a9e8b538aecb7581533b9c1d19faed
-         dlist-0.5-645574c332014f535d55f2387855cdd7
-         ghc-prim-0.2.0.0-23f345e1ec26a64d5ebc768bd0b2a5d9
-         hashable-1.1.2.3-1e9e274afb8e07dab57c2a975698461b
-         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
-         old-locale-1.0.0.4-b1d945ebea59a524cba400a524cb40aa
-         syb-0.3.7-a269c050536d4890f37a20513844e800
-         template-haskell-2.7.0.0-a8fc6af10e016d4c8fff69196193b62c
-         text-0.11.2.3-6d44323283fc0f3935743a72b4424942
-         time-1.4-b8e1c3d423daa1e2c5470a82caf23b52
-         unordered-containers-0.1.4.6-3501841bb7a7f313c99e53e7965a1a02
-         vector-0.10.0.1-fdf8e0c3f3c1cae1113ab97c34aa5c14
+depends: attoparsec-0.10.4.0-d9fd97cfc1a1748b3cde35adf7fd233b
+         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
+         blaze-builder-0.3.1.1-71a2ae53eb5daf9e6673db8b47b3b6b5
+         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
+         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
+         deepseq-1.3.0.1-5cc4cd89bdc2e8f6db1833d95ec36926
+         dlist-0.5-6480552fbf191185cc86167748682e90
+         ghc-prim-0.3.0.0-d5221a8c8a269b66ab9a07bdc23317dd
+         hashable-1.1.2.5-e0f2541518f84d3123a819112b4ffe20
+         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
+         old-locale-1.0.0.5-6729cb9d9cc62d150655de8fc5401b91
+         syb-0.4.0-c48d52f3188b986ddaa9dd9ae40072f8
+         template-haskell-2.8.0.0-2f3447bb22ecbbb93fd4d823f6841241
+         text-0.11.3.1-5af30448b2c3a30eee31b3ea9b549812
+         time-1.4.0.1-10dc4804a19dc0000fab79908f1a9f50
+         unordered-containers-0.2.3.0-c7952fe8bed178bdf8ed4d090730c9da
+         vector-0.10.0.1-869166d5d49db46ce6c328ea5f8defbf
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-aeson-0.6.0.2/html/aeson.haddock
-haddock-html: /usr/local/share/doc/hs-aeson-0.6.0.2/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-aeson-0.6.2.1/html/aeson.haddock
+haddock-html: /usr/local/share/doc/hs-aeson-0.6.2.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
